==> aws-sdk-cpp-1.11.667-1-x86_64.pkg.tar.zst: usr/include/aws/autoscaling/AutoScalingErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/autoscaling/AutoScaling_EXPORTS.h>

namespace Aws
{
namespace AutoScaling
{
enum class AutoScalingErrors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ACTIVE_INSTANCE_REFRESH_NOT_FOUND_FAULT= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  ALREADY_EXISTS_FAULT,
  INSTANCE_REFRESH_IN_PROGRESS_FAULT,
  INVALID_NEXT_TOKEN,
  IRREVERSIBLE_INSTANCE_REFRESH_FAULT,
  LIMIT_EXCEEDED_FAULT,
  RESOURCE_CONTENTION_FAULT,
  RESOURCE_IN_USE_FAULT,
  SCALING_ACTIVITY_IN_PROGRESS_FAULT,
  SERVICE_LINKED_ROLE_FAILURE
};

class AWS_AUTOSCALING_API AutoScalingError : public Aws::Client::AWSError<AutoScalingErrors>
{
public:
  AutoScalingError() {}
  AutoScalingError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}
  AutoScalingError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}
  AutoScalingError(const Aws::Client::AWSError<AutoScalingErrors>& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}
  AutoScalingError(Aws::Client::AWSError<AutoScalingErrors>&& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace AutoScalingErrorMapper
{
  AWS_AUTOSCALING_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace AutoScaling
} // namespace Aws

==> aws-sdk-cpp-1.11.696-1-x86_64.pkg.tar.zst: usr/include/aws/autoscaling/AutoScalingErrors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/autoscaling/AutoScaling_EXPORTS.h>
#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>

namespace Aws {
namespace AutoScaling {
enum class AutoScalingErrors {
  // From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7,                // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8,  // SDK should never allow
  MISSING_PARAMETER = 9,             // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  ACTIVE_INSTANCE_REFRESH_NOT_FOUND_FAULT = static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  ALREADY_EXISTS_FAULT,
  IDEMPOTENT_PARAMETER_MISMATCH,
  INSTANCE_REFRESH_IN_PROGRESS_FAULT,
  INVALID_NEXT_TOKEN,
  IRREVERSIBLE_INSTANCE_REFRESH_FAULT,
  LIMIT_EXCEEDED_FAULT,
  RESOURCE_CONTENTION_FAULT,
  RESOURCE_IN_USE_FAULT,
  SCALING_ACTIVITY_IN_PROGRESS_FAULT,
  SERVICE_LINKED_ROLE_FAILURE
};

class AWS_AUTOSCALING_API AutoScalingError : public Aws::Client::AWSError<AutoScalingErrors> {
 public:
  AutoScalingError() {}
  AutoScalingError(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}
  AutoScalingError(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}
  AutoScalingError(const Aws::Client::AWSError<AutoScalingErrors>& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}
  AutoScalingError(Aws::Client::AWSError<AutoScalingErrors>&& rhs) : Aws::Client::AWSError<AutoScalingErrors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace AutoScalingErrorMapper {
AWS_AUTOSCALING_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

}  // namespace AutoScaling
}  // namespace Aws
